@@ -106,8 +106,8 @@ class UserManagement(APIResource):
     def get_user_list(cls, username: str, admin_token: str = None) -> WhatifyResponse:
         ret_val = {}
         resp = cls.list(filter_={'username': [username]}, api_key=admin_token)
-        if resp and 'result' in resp and len(resp['result']) == 1:
-            ret_val = resp['result'][0]
+        if resp and 'hits' in resp and len(resp['hits']) == 1:
+            ret_val = resp['hits'][0]
         return ret_val
 
     @classmethod
