@@ -27,6 +27,8 @@ class MyWhatify:
     #######    API's      #######
     #############################
     user_token = None
+    magento_magento2url = None
+    magento_headers = None
 
     @classmethod
     def __init__(cls):
@@ -101,7 +103,75 @@ class MyWhatify:
             with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
                 my_toolkit.UserManagement.impersonate(user_id=user_id, admin_token=admin_token)
 
+    #############################
+    ######  Magento API's  ######
+    #############################
+    @classmethod
+    def set_demo_site_api(cls):
+        '''
+            set our default store for testing
+        '''
+        cls.set_magento_api(magento2url='http://whatify.tempurl.co.il/whatify/api/db/table/sales_order/limit/3/page/1/',
+                            magento_header={'Whatify-Merchant-ID': 'j458vgjeDVHe564y3435',
+                                            'Whatify-API-Key': 'n6hcr4_6beuvthg45vw_3v5te5yb565454vbn'})
 
+    @classmethod
+    def set_magento_api(cls, magento2url: str = None, magento_header: dict = None):
+        '''
+        setting the magento store api connection details
+        :param magento2url: the url of the store
+        :param magento_header: dict with the relevant headers
+        :return: None
+        '''
+        if magento2url:
+            cls.magento_magento2url = magento2url
+        if magento_header:
+            cls.magento_headers = magento_header
+
+    @classmethod
+    def get_magento(cls, table: str = None, page: str = None, limit: str = None, add_total: str = None,
+                    only_total: str = None):
+        '''
+        GET magento store api
+        :param table: the specific table
+        :param page: the page number
+        :param limit: the page limit
+        :param add_total:
+        :param only_total:
+        :return:
+        '''
+        return cls.magento_api(api_method='GET', table=table, page=page, limit=limit, add_total=add_total,
+                               only_total=only_total)
+
+    @classmethod
+    def post_magento(cls, body: str = None, table: str = None, page: str = None, limit: str = None,
+                     add_total: str = None, only_total: str = None):
+        '''
+        POST magento store api
+        :param body:
+        :param table: the specific table
+        :param page: the page number
+        :param limit: the page limit
+        :param add_total:
+        :param only_total:
+        :return:
+        '''
+        return cls.magento_api(api_method='POST', body=body, table=table, page=page, limit=limit, add_total=add_total,
+                               only_total=only_total)
+
+    @classmethod
+    def magento_api(cls, api_method: str = None, body: str = None, table: str = None, page: str = None,
+                    limit: str = None, add_total: str = None, only_total: str = None):
+        base_url = cls.magento_magento2url + '?'
+        base_vars = ['table', 'page', 'limit', 'add_total', 'only_total']
+        for var in base_vars:
+            if locals().get(var) is not None:
+                base_url += str(var) + '=' + str(locals().get(var)) + '&'
+        base_url = base_url[:-1]
+
+        ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
+        retval = pd.DataFrame.from_dict(ret_json.to_dict(), orient='columns')
+        return retval
 
     #############################
     #######    API's      #######
@@ -394,6 +464,11 @@ class MyWhatify:
         func = switcher.get(method.upper(), lambda: "Invalid api method")
         return func(url=url, headers=headers, body=body, params=params, user_token=user_token)
 
+    @classmethod
+    def base_api(cls, url, method, headers=None, body=None, params=None, user_token=None):
+        return APIRequestor().request_base(method=method, url=url, headers=headers, body=body, params=params,
+                                           api_key=user_token)
+
     @classmethod
     def test_api(cls, url, method, expected_response, headers=None, body=None, params=None, user_token=None):
         expected_payload, expected_status_code = expected_response
